@@ -955,6 +955,7 @@ func ProvisionerToCertificates(p *linkedca.Provisioner) (provisioner.Interface,
 			Name:                   p.Name,
 			ServiceAccounts:        cfg.ServiceAccounts,
 			ProjectIDs:             cfg.ProjectIds,
+			OrganizationID:         cfg.OrganizationId,
 			DisableCustomSANs:      cfg.DisableCustomSans,
 			DisableTrustOnFirstUse: cfg.DisableTrustOnFirstUse,
 			DisableSSHCAUser:       cfg.DisableSshCaUser,
@@ -1097,6 +1098,7 @@ func ProvisionerToLinkedca(p provisioner.Interface) (*linkedca.Provisioner, erro
 					GCP: &linkedca.GCPProvisioner{
 						ServiceAccounts:        p.ServiceAccounts,
 						ProjectIds:             p.ProjectIDs,
+						OrganizationId:         p.OrganizationID,
 						DisableCustomSans:      p.DisableCustomSANs,
 						DisableTrustOnFirstUse: p.DisableTrustOnFirstUse,
 						DisableSshCaUser:       p.DisableSSHCAUser,
